import { FailedFetchBasicPageError, FailedFetchBasicPagesError } from '@/errors'
import DefaultLayout from '@/layouts/DefaultLayout/DefaultLayout'
import { mdxComponents } from '@/lib/mdx-components'
import { fetchBasicPages } from '@/services/content-service'
import { MDXClient } from 'next-mdx-remote-client'
import {
  serialize
} from 'next-mdx-remote-client/serialize'
import { NextSeo } from 'next-seo'

export async function getStaticPaths () {
  const res = await fetchBasicPages(['path'])

  if (!res.ok) {
    throw new FailedFetchBasicPagesError(await res.text())
  }

  const pages = (await res.json()).data

  const paths = {
    paths: pages.map(page => ({
      params: {
        path: page.path?.split('/') // about/page -> [about, page]
          .filter(p => !!p) ?? [] // deal with paths starting with '/'
      }
    })),
    fallback: true // false or "blocking"
  }

  return paths
}
export async function getStaticProps ({ params }) {
  const { path } = params
  const res = await fetchBasicPages([], {
    path: {
      _eq: path?.join('/') ?? null
    }
  })

  if (!res.ok) {
    throw new FailedFetchBasicPageError(path, await res.text())
  }

  const page = (await res.json()).data.at(0)

  if (!page) {
    return {
      notFound: true
    }
  }

  const { content, title } = page
  const mdxSource = await serialize({ source: content })

  return {
    props: {
      title,
      mdxSource
    }
  }
}

export default function BasicPage ({ title, mdxSource }) {
  return (
    <DefaultLayout>
      <NextSeo
        title={title} description={undefined} openGraph={
          {
            title,
            description: undefined
          }
        }
      />
      <div>
        <MDXClient {...mdxSource} components={mdxComponents} />
      </div>
    </DefaultLayout>
  )
}
