import showdown from 'showdown'

const baseUrl = process.env.NEXT_PUBLIC_CONTENT_API_BASE_URL

// @ts-ignore
export const fetchPosts = async (...args) => fetchItems('post', ...args)
export const fetchBookReviews = async (...args) => fetchItems('book_review', ...args)
export const fetchBasicPages = async (...args) => fetchItems('basic_pages', ...args)
export const fetchCV = async (...args) => fetchItems('cv', ...args)

export async function fetchItems (type, fields = undefined, filter = undefined) {
  const url = new URL(`${baseUrl}/items/${type}`)
  console.log(`Getting items '${type}' with fields`, fields, 'and filter', filter)

  if (fields?.length) {
    url.searchParams.append('fields', fields.join(','))
  }

  if (filter) {
    url.searchParams.append(
      'filter',
      JSON.stringify(filter)
    )
  }

  return await apiFetch(url.toString())
}

export function getTagsFromPosts (posts) {
  const allTags = {}

  for (const post of posts) {
    if (!post.tags) { continue }

    for (const tag of post.tags) {
      allTags[tag] = !allTags[tag] ? 1 : allTags[tag] + 1
    }
  }

  return allTags
}

export function markdownToHtml (content) {
  const converter = new showdown.Converter({
    tables: true,
    tablesHeaderId: true
  })
  const html = converter.makeHtml(content)
  return html
}

async function apiFetch (...args) {
  console.log('API fetch:', args)
  // @ts-ignore
  const res = await fetch(...args)
  console.log('API fetch response:', res.status, res.statusText)
  return res
}
